@@ -63,7 +63,8 @@ var defaultOpts = {
   view: defaultView,
   initialState: {},
   middleware: [],
-  welcome: ''
+  welcome: '',
+  title: ''
 };
 
 var cycleShell = function cycleShell(userUpdate) {
@@ -75,9 +76,10 @@ var cycleShell = function cycleShell(userUpdate) {
   var initialState = _defaultOpts$opts.initialState;
   var middleware = _defaultOpts$opts.middleware;
   var welcome = _defaultOpts$opts.welcome;
+  var title = _defaultOpts$opts.title;
 
 
-  var initState = { welcome: welcome, log: {}, user: initialState };
+  var initState = { welcome: welcome, log: {}, user: { title: title } };
 
   var _vdux = (0, _dom2.default)({
     reducer: _reducer2.default,
